@@ -3,6 +3,7 @@ import logging
 import sys
 
 import click
+from sqlalchemy_utils import database_exists, create_database
 
 from aop2db.aop.importer import import_aop_data
 from aop2db.utils import set_conn
@@ -33,10 +34,9 @@ def conn(conn_str: str):
     conn_str
         A python compatible SQL connection string. Drivers (e.g. pymysql) will need to be downloaded manually.
     """
-    engine = create_engine(conn_str, convert_unicode=True)
 
-    # Check if connection string works
-    engine.connect()
+    if not database_exists(conn_str):
+        create_database(conn_str)
 
     set_conn(conn_string=conn_str)
 
